@@ -6,12 +6,17 @@
 
 #pragma once
 
+#include "config-NetworkManagerQt.h"
+
 #include <unordered_map>
 
 #include <QDate>
 #include <QObject>
 #include <QTimer>
 
+#if HAVE_NetworkManagerQt
+#include <NetworkManagerQt/Manager>
+#endif
 #include <KPluginMetaData>
 
 #include "potdprovider.h"
@@ -27,6 +32,9 @@ public:
     PotdClient(const KPluginMetaData &metadata, const QVariantList &args, QObject *parent = nullptr);
 
     void updateSource(bool refresh = false);
+#if HAVE_NetworkManagerQt
+    void setUpdateOverMeteredConnection(int value);
+#endif
 
     KPluginMetaData m_metadata;
     PotdProviderData m_data;
@@ -58,6 +66,9 @@ private:
 
     QString m_identifier;
     QVariantList m_args;
+#if HAVE_NetworkManagerQt
+    int m_doesUpdateOverMeteredConnection = 0;
+#endif
 
     friend class PotdEngine;
 };
@@ -89,6 +100,9 @@ private Q_SLOTS:
     void forceUpdateSource();
     void slotDone(PotdClient *client, bool success);
     void slotPrepareForSleep(bool sleep);
+#if HAVE_NetworkManagerQt
+    void slotConnectivityChanged(NetworkManager::Connectivity connectivity);
+#endif
 
 private:
     void loadPluginMetaData();
